polyfemos.scripts.test_front_paths — polyfemos 0.3.29 documentation

# polyfemos.scripts.test_front_paths

Test polyfemos frontend paths

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.scripts.test_front_paths.` `check_paths`(paths, key, priority, ford)
  Parameters

    - paths (dict) – dictionary containing paths

    - key (str) –

    - priority (str) –

    - ford (str) – “file” or “dir”

`polyfemos.scripts.test_front_paths.` `main`(argv=None)

  Recursively checks folders for YAML files for defined paths.

  Parameters

    argv (list) – command line arguments